@@ -2,10 +2,9 @@
 #'
 #' Takes any vector of languages and return longitude.
 #' @param x A character vector of the languages (can be written in lower case)
-#' @param glottolog.source A character vector that define which glottolog database is used: 'original' or 'modified' (by default)
 #' @param map.orientation A character verctor with values "Pacific" and "Atlantic". It distinguishes Pacific-centered and Atlantic-centered maps. By default is "Pacific".
 #' @author George Moroz <agricolamz@gmail.com>
-#' @seealso \code{\link{aff.lang}}, \code{\link{area.lang}}, \code{\link{country.lang}}, \code{\link{iso.lang}}, \code{\link{lat.lang}}
+#' @seealso \code{\link{aff.lang}}, \code{\link{area.lang}}, \code{\link{iso.lang}}, \code{\link{lat.lang}}
 #' @examples
 #' lat.lang('Adyghe')
 #' long.lang('Adyghe')
@@ -15,20 +14,14 @@
 #' @export
 
 long.lang <- function(x,
-                      map.orientation = "Pacific",
-                      glottolog.source = "modified") {
+                      map.orientation = "Pacific") {
   if (typeof(x) == "list") {
     x <- unlist(x)
   }
-  ifelse(
-    grepl(glottolog.source, "original"),
-    glottolog <- lingtypology::glottolog.original,
-    glottolog <- lingtypology::glottolog.modified
-  )
+  glottolog <- lingtypology::glottolog
   result <- vapply(x, function(y) {
     ifelse(
-      is.glottolog(y, response = TRUE,
-                   glottolog.source = glottolog.source) == TRUE,
+      is.glottolog(y, response = TRUE) == TRUE,
       glottolog[tolower(glottolog$language) %in% tolower(y),]$longitude,
       NA_real_
     )
